@@ -1,6 +1,7 @@
 from voicebox_pytorch.voicebox_pytorch import (
     Transformer,
+    EncodecVoco,
     VoiceBox,
     DurationPredictor,
-    ConditionalFlowMatcherWrapper
+    ConditionalFlowMatcherWrapper,
 )
